@@ -3,8 +3,10 @@
 //
 // Author:
 //   Aaron Bockover <abockover@novell.com>
+//   Julien Moutte <julien@fluendo.com>
 //
 // Copyright (C) 2005-2008 Novell, Inc.
+// Copyright (C) 2010 Fluendo S.A.
 //
 // Permission is hereby granted, free of charge, to any person obtaining
 // a copy of this software and associated documentation files (the
@@ -36,57 +38,56 @@
 // Private Functions
 // ---------------------------------------------------------------------------
 
-static gboolean
-bp_iterate_timeout_handler (BansheePlayer *player)
-{
-    g_return_val_if_fail (IS_BANSHEE_PLAYER (player), FALSE);
-    
-    if(player->iterate_cb != NULL) {
-        player->iterate_cb (player);
-    }
-    
-    return TRUE;
-}
-
-static void
-bp_iterate_timeout_start (BansheePlayer *player)
-{
-    g_return_if_fail (IS_BANSHEE_PLAYER(player));
-
-    if (player->iterate_timeout_id == 0) {
-        player->iterate_timeout_id = g_timeout_add (200, 
-            (GSourceFunc)bp_iterate_timeout_handler, player);
-    }
-}
-
-static void
-bp_iterate_timeout_stop (BansheePlayer *player)
-{
-    g_return_if_fail (IS_BANSHEE_PLAYER (player));
-    
-    if (player->iterate_timeout_id != 0) {
-        g_source_remove (player->iterate_timeout_id);
-        player->iterate_timeout_id = 0;
-    }
-}
-
 static void
 bp_pipeline_set_state (BansheePlayer *player, GstState state)
 {
     g_return_if_fail (IS_BANSHEE_PLAYER (player));
     
-    if (state == GST_STATE_NULL || state == GST_STATE_PAUSED) {
-        bp_iterate_timeout_stop (player);
-    }
-    
     if (GST_IS_ELEMENT (player->playbin)) {
         player->target_state = state;
         gst_element_set_state (player->playbin, state);
     }
-    
-    if (state == GST_STATE_PLAYING) {
-        bp_iterate_timeout_start (player);
+}
+
+static void
+bp_lookup_for_subtitle (BansheePlayer *player, const gchar *uri)
+{
+    gchar *scheme, *filename, *subfile, *dot, *suburi;
+    int j;
+    // Always enable rendering of subtitles
+    gint flags;
+    g_object_get (G_OBJECT (player->playbin), "flags", &flags, NULL);
+    flags |= (1 << 2);//GST_PLAY_FLAG_TEXT
+    g_object_set (G_OBJECT (player->playbin), "flags", flags, NULL);
+
+    bp_debug ("[subtitle]: lookup for subtitle for video file.");
+    scheme = g_uri_parse_scheme (uri);
+    static gchar *subtitle_extensions[] = { ".srt", ".sub", ".smi", ".txt", ".mpl", ".dks", ".qtx" };
+    if (scheme == NULL || strcmp (scheme, "file") != 0) {
+        g_free (scheme);
+        return;
     }
+    g_free (scheme);
+
+    dot = g_strrstr (uri, ".");
+    if (dot == NULL)
+        return;
+    filename = g_filename_from_uri (g_strndup (uri, dot - uri), NULL, NULL);
+
+    for (j = 0; j < G_N_ELEMENTS (subtitle_extensions); j++) {
+        subfile = g_strconcat (filename, subtitle_extensions[j], NULL);
+        if (g_file_test (subfile, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {
+            bp_debug ("[subtitle]: Found srt file: %s", subfile);
+            suburi = g_filename_to_uri (subfile, NULL, NULL);
+            g_object_set (G_OBJECT (player->playbin), "suburi", suburi, NULL);
+            g_free (suburi);
+            g_free (subfile);
+            g_free (filename);
+            return;
+        }
+        g_free (subfile);
+    }
+    g_free (filename);
 }
 
 // ---------------------------------------------------------------------------
@@ -98,8 +99,12 @@ bp_destroy (BansheePlayer *player)
 {
     g_return_if_fail (IS_BANSHEE_PLAYER (player));
     
-    if (player->mutex != NULL) {
-        g_mutex_free (player->mutex);
+    if (player->video_mutex != NULL) {
+        g_mutex_free (player->video_mutex);
+    }
+
+    if (player->replaygain_mutex != NULL) {
+        g_mutex_free (player->replaygain_mutex);
     }
     
     if (player->cdda_device != NULL) {
@@ -122,8 +127,9 @@ bp_new ()
 {
     BansheePlayer *player = g_new0 (BansheePlayer, 1);
     
-    player->mutex = g_mutex_new ();
-    
+    player->video_mutex = g_mutex_new ();
+    player->replaygain_mutex = g_mutex_new ();
+
     return player;
 }
 
@@ -134,7 +140,7 @@ bp_initialize_pipeline (BansheePlayer *player)
 }
 
 P_INVOKE gboolean
-bp_open (BansheePlayer *player, const gchar *uri)
+bp_open (BansheePlayer *player, const gchar *uri, gboolean maybe_video)
 {
     GstState state;
     
@@ -163,6 +169,11 @@ bp_open (BansheePlayer *player, const gchar *uri)
     // Pass the request off to playbin
     g_object_set (G_OBJECT (player->playbin), "uri", uri, NULL);
     
+    if (maybe_video) {
+        // Lookup for subtitle files with same name/folder
+        bp_lookup_for_subtitle (player, uri);
+    }
+
     player->in_gapless_transition = FALSE;
     
     return TRUE;
@@ -180,7 +191,7 @@ bp_stop (BansheePlayer *player, gboolean nullstate)
         state = GST_STATE_NULL;
     }
     
-    bp_debug ("bp_stop: setting state to %s",
+    bp_debug2 ("bp_stop: setting state to %s",
         state == GST_STATE_NULL ? "GST_STATE_NULL" : "GST_STATE_PAUSED");
     
     player->in_gapless_transition = FALSE;
@@ -202,11 +213,14 @@ bp_play (BansheePlayer *player)
 }
 
 P_INVOKE gboolean
-bp_set_next_track (BansheePlayer *player, const gchar *uri)
+bp_set_next_track (BansheePlayer *player, const gchar *uri, gboolean maybe_video)
 {
     g_return_val_if_fail (IS_BANSHEE_PLAYER (player), FALSE);
     g_return_val_if_fail (player->playbin != NULL, FALSE);
     g_object_set (G_OBJECT (player->playbin), "uri", uri, NULL);
+    if (maybe_video) {
+        bp_lookup_for_subtitle (player, uri);
+    }
     return TRUE;
 }
 
@@ -293,15 +307,38 @@ bp_supports_gapless (BansheePlayer *player)
 #endif //ENABLE_GAPLESS
 }
 
+P_INVOKE gboolean
+bp_supports_stream_volume (BansheePlayer *player)
+{
+    g_return_val_if_fail (IS_BANSHEE_PLAYER (player), FALSE);
+    return player->supports_stream_volume;
+}
+
+P_INVOKE gboolean
+bp_audiosink_has_volume (BansheePlayer *player)
+{
+    g_return_val_if_fail (IS_BANSHEE_PLAYER (player), FALSE);
+    return player->audiosink_has_volume;
+}
+
 P_INVOKE void
 bp_set_volume (BansheePlayer *player, gdouble volume)
 {
+    GParamSpec *volume_spec;
+    GValue value = { 0, };
+
     g_return_if_fail (IS_BANSHEE_PLAYER (player));
-    g_return_if_fail (GST_IS_ELEMENT (player->playbin));
+    g_return_if_fail (GST_IS_ELEMENT(player->volume));
 
     player->current_volume = CLAMP (volume, 0.0, 1.0);
-    g_object_set (player->playbin, "volume", player->current_volume, NULL);
-    _bp_rgvolume_print_volume (player);
+    volume_spec = g_object_class_find_property (G_OBJECT_GET_CLASS (player->volume), "volume");
+    g_value_init (&value, G_TYPE_DOUBLE);
+    g_value_set_double (&value, player->current_volume);
+    g_param_value_validate (volume_spec, &value);
+
+    g_object_set_property (G_OBJECT (player->volume), "volume", &value);
+    g_value_unset (&value);
+    _bp_rgvolume_print_volume(player);
 }
 
 P_INVOKE gdouble
@@ -311,6 +348,12 @@ bp_get_volume (BansheePlayer *player)
     return player->current_volume;
 }
 
+P_INVOKE void
+bp_set_volume_changed_callback (BansheePlayer *player, BansheePlayerVolumeChangedCallback cb)
+{
+    SET_CALLBACK (volume_changed_cb);
+}
+
 P_INVOKE gboolean
 bp_get_pipeline_elements (BansheePlayer *player, GstElement **playbin, GstElement **audiobin, GstElement **audiotee)
 {
@@ -347,12 +390,6 @@ bp_set_state_changed_callback (BansheePlayer *player, BansheePlayerStateChangedC
     SET_CALLBACK (state_changed_cb);
 }
 
-P_INVOKE void
-bp_set_iterate_callback (BansheePlayer *player, BansheePlayerIterateCallback cb)
-{
-    SET_CALLBACK (iterate_cb);
-}
-
 P_INVOKE void
 bp_set_buffering_callback (BansheePlayer *player, BansheePlayerBufferingCallback cb)
 {
@@ -385,3 +422,76 @@ bp_set_about_to_finish_callback (BansheePlayer *player, BansheePlayerAboutToFini
 {
     SET_CALLBACK (about_to_finish_cb);
 }
+
+P_INVOKE void
+bp_set_subtitle_uri (BansheePlayer *player, const gchar *uri)
+{
+    g_return_if_fail (IS_BANSHEE_PLAYER (player));
+    gint64 pos = -1;
+    GstState state;
+    GstFormat format = GST_FORMAT_BYTES;
+    gboolean paused = FALSE;
+
+    // Gstreamer playbin do not support to set suburi during playback
+    // so have to stop/play and seek
+    gst_element_get_state (player->playbin, &state, NULL, 0);
+    paused = (state == GST_STATE_PAUSED);
+    if (state >= GST_STATE_PAUSED) {
+        gst_element_query_position (player->playbin, &format, &pos);
+        gst_element_set_state (player->playbin, GST_STATE_READY);
+        // Force to wait asynch operation
+        gst_element_get_state (player->playbin, &state, NULL, -1);
+    }
+
+    g_object_set (G_OBJECT (player->playbin), "suburi", uri, NULL);
+    gst_element_set_state (player->playbin, paused ? GST_STATE_PAUSED : GST_STATE_PLAYING);
+
+    // Force to wait asynch operation
+    gst_element_get_state (player->playbin, &state, NULL, -1);
+
+    if (pos != -1) {
+        gst_element_seek_simple (player->playbin, format, GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_KEY_UNIT, pos);
+    }
+}
+
+P_INVOKE gchar *
+bp_get_subtitle_uri (BansheePlayer *player)
+{
+    gchar *uri;
+    g_return_val_if_fail (IS_BANSHEE_PLAYER (player), "");
+    g_object_get (G_OBJECT (player->playbin), "suburi", &uri, NULL);
+    return uri;
+}
+
+P_INVOKE gchar *
+bp_get_subtitle_description (BansheePlayer *player, int i)
+{
+    gchar *code;
+    gchar *desc = NULL;
+    GstTagList *tags = NULL;
+
+    g_return_val_if_fail (IS_BANSHEE_PLAYER (player), NULL);
+
+    g_signal_emit_by_name (G_OBJECT (player->playbin), "get-text-tags", i, &tags);
+    if (G_LIKELY(tags)) {
+        gst_tag_list_get_string (tags, GST_TAG_LANGUAGE_CODE, &code);
+        gst_tag_list_free (tags);
+
+        g_return_val_if_fail (code != NULL, NULL);
+
+        // ISO 639-2 undetermined language
+        if (strcmp ((const gchar *)code, "und") == 0) {
+            return NULL;
+        }
+        bp_debug ("[subtitle]: iso 639-2 subtitle code %s", code);
+#ifdef HAVE_GST_0_10_26
+        desc = (gchar *) gst_tag_get_language_name ((const gchar *)&code);
+        bp_debug ("[subtitle]: subtitle language: %s", desc);
+#else
+        desc = g_strdup (code);
+#endif
+
+        g_free (code);
+    }
+    return desc;
+}
