@@ -73,6 +73,8 @@ namespace Beroe
 
         private static void Startup ()
         {
+            Application.InitializePaths ();
+
             ThreadAssist.InitializeMainThread ();
 
             ServiceManager.Initialize ();
@@ -111,7 +113,7 @@ namespace Beroe
                 // FIXME: Using Process.Start sucks, but DBus doesn't let you specify
                 // extra command line arguments
                 DBusConnection.Disconnect ("CollectionIndexer");
-                Process.Start ("banshee-1", builder.ToString ());
+                Process.Start ("banshee", builder.ToString ());
                 // Bus.Session.StartServiceByName (DBusConnection.DefaultBusName);
                 // Bus.Session.Iterate ();
             }
