@@ -26,6 +26,8 @@
 // WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 //
 
+using Hyena;
+
 using System;
 using System.IO;
 using System.Collections.Generic;
@@ -34,8 +36,6 @@ using System.Text.RegularExpressions;
 
 using Mono.Unix;
 
-using Hyena;
-
 namespace Banshee.Base
 {
     public static class CoverArtSpec
@@ -87,12 +87,16 @@ namespace Banshee.Base
 
         public static string CreateArtistAlbumId (string artist, string album)
         {
-            if (artist == unknown_artist || artist == unknown_artist_tr || album == unknown_album || album == unknown_album_tr) {
+            if (album == null || album == unknown_album || album == unknown_album_tr) {
+                // do not attempt to group unknown album tracks together
                 return null;
             }
 
-            string digestible = String.Format ("{0}\t{1}", artist ?? "", album ?? "");
+            if (artist == null || artist == unknown_artist || artist == unknown_artist_tr) {
+                return null;
+            }
 
+            string digestible = String.Format ("{0}\t{1}", artist, album);
             return String.Format ("album-{0}", Digest (digestible));
         }
 
