@@ -40,7 +40,7 @@ namespace Banshee.Streaming
         // This is a short list of video types that TagLib# might not support but that
         // we want to make sure are recognized as videos
         private static readonly ExtensionSet VideoExtensions = new ExtensionSet (
-            "avi", "divx", "dv", "f4p", "f4v", "flv", "m4v", "mkv", "mov", "ogv", "qt", "ts");
+            "avi", "divx", "dv", "f4p", "f4v", "flv", "m4v", "mkv", "mov", "ogv", "qt", "ts", "webm");
 
         public static TagLib.File ProcessUri (SafeUri uri)
         {
@@ -54,6 +54,7 @@ namespace Banshee.Streaming
                 }
                 return file;
             } catch (Exception e) {
+                Hyena.Log.DebugFormat ("Encountered a problem processing: {0}", uri.AbsoluteUri);
                 Hyena.Log.DebugException (e);
                 return null;
             }
@@ -283,13 +284,6 @@ namespace Banshee.Streaming
 
         public static bool SaveToFile (TrackInfo track, bool write_metadata, bool write_rating_and_play_count)
         {
-            // FIXME taglib# does not seem to handle writing metadata to video files well at all atm
-            // so not allowing
-            if ((track.MediaAttributes & TrackMediaAttributes.VideoStream) != 0) {
-                Hyena.Log.DebugFormat ("Avoiding 100% cpu bug with taglib# by not writing metadata to video file {0}", track);
-                return false;
-            }
-
             // Note: this should be kept in sync with the metadata read in StreamTagger.cs
             TagLib.File file = ProcessUri (track.Uri);
             if (file == null) {
