@@ -28,12 +28,10 @@
 //
 
 using System;
-using System.Data;
 using System.Reflection;
 using System.Text;
 using System.Threading;
 using Mono.Unix;
-using Mono.Data.Sqlite;
 
 using Hyena;
 using Hyena.Jobs;
@@ -731,6 +729,8 @@ namespace Banshee.Database
                 // Make paths not relative for Music Library items
                 string library_path = Banshee.Library.LibrarySource.OldLocationSchema.Get (Banshee.Library.MusicLibrarySource.GetDefaultBaseDirectory ());
                 if (library_path != null) {
+                    connection.AddFunction<MigratePartialFunction> ();
+
                     int podcast_src_id = connection.Query<int> ("SELECT PrimarySourceID FROM CorePrimarySources WHERE StringID = 'PodcastSource-PodcastLibrary'");
 
                     connection.Execute (@"
@@ -743,6 +743,8 @@ namespace Banshee.Database
                         UPDATE CoreTracks SET Uri = BANSHEE_MIGRATE_PARTIAL(?, Uri)
                         WHERE UriType = 1
                           AND PrimarySourceID = ?", podcast_path, podcast_src_id);
+
+                    connection.RemoveFunction<MigratePartialFunction> ();
                 }
             } catch (Exception e) {
                 Hyena.Log.Exception (e);
@@ -1393,7 +1395,7 @@ namespace Banshee.Database
             );
 
             int count = 0;
-            using (System.Data.IDataReader reader = ServiceManager.DbConnection.Query (select_command)) {
+            using (var reader = ServiceManager.DbConnection.Query (select_command)) {
                 while (reader.Read ()) {
                     DatabaseTrackInfo track = null;
                     try {
