@@ -53,19 +53,19 @@ namespace Banshee.FileSystemQueue
         private bool actions_loaded = false;
         private bool play_enqueued = false;
         private string path_to_play;
-        
-        public FileSystemQueueSource () : base (Catalog.GetString ("File System Queue"), 
+
+        public FileSystemQueueSource () : base (Catalog.GetString ("File System Queue"),
             Catalog.GetString ("File System Queue"), "file-system-queue", 30)
         {
             TypeUniqueId = "file-system-queue";
-            Properties.SetString ("Icon.Name", "system-file-manager");
+            Properties.SetStringList ("Icon.Name", "system-file-manager");
             Properties.Set<bool> ("AutoAddSource", false);
             IsLocal = true;
-            
+
             ServiceManager.Get<DBusCommandService> ().ArgumentPushed += OnCommandLineArgument;
-            
+
             AfterInitialized ();
-            
+
             InterfaceActionService uia_service = ServiceManager.Get<InterfaceActionService> ();
             uia_service.GlobalActions.AddImportant (
                 new ActionEntry ("ClearFileSystemQueueAction", Stock.Clear,
@@ -73,29 +73,29 @@ namespace Banshee.FileSystemQueue
                     Catalog.GetString ("Remove all tracks from the file system queue"),
                     OnClearFileSystemQueue)
             );
-            
+
             uia_service.GlobalActions.Add (new ToggleActionEntry [] {
                 new ToggleActionEntry ("ClearFileSystemQueueOnQuitAction", null,
-                    Catalog.GetString ("Clear on Quit"), null, 
-                    Catalog.GetString ("Clear the file system queue when quitting"), 
+                    Catalog.GetString ("Clear on Quit"), null,
+                    Catalog.GetString ("Clear the file system queue when quitting"),
                     OnClearFileSystemQueueOnQuit, ClearOnQuitSchema.Get ())
             });
-            
+
             uia_service.UIManager.AddUiFromResource ("GlobalUI.xml");
-            
+
             Properties.SetString ("ActiveSourceUIResource", "ActiveSourceUI.xml");
             Properties.SetString ("GtkActionPath", "/FileSystemQueueContextMenu");
-            
+
             actions_loaded = true;
-            
+
             UpdateActions ();
-            ServiceManager.SourceManager.ActiveSourceChanged += delegate { Banshee.Base.ThreadAssist.ProxyToMain (UpdateActions); };
+            ServiceManager.SourceManager.ActiveSourceChanged += delegate { ThreadAssist.ProxyToMain (UpdateActions); };
             TrackModel.Reloaded += OnTrackModelReloaded;
-            
+
             Reload ();
 
             play_enqueued = ApplicationContext.CommandLine.Contains ("play-enqueued");
-            
+
             foreach (string path in ApplicationContext.CommandLine.Files) {
                 // If it looks like a URI with a protocol, leave it as is
                 if (System.Text.RegularExpressions.Regex.IsMatch (path, "^\\w+\\:\\/")) {
@@ -106,8 +106,10 @@ namespace Banshee.FileSystemQueue
                     Enqueue (Path.GetFullPath (path));
                 }
             }
+
+            StorageName = null;
         }
-        
+
         public void Enqueue (string path)
         {
             try {
@@ -127,7 +129,7 @@ namespace Banshee.FileSystemQueue
                             if (args.Error != null || path_to_play != null) {
                                 return;
                             }
-                            
+
                             path_to_play = args.Path;
                             if (args.Track == null) {
                                 // Play immediately if the track is already in the source,
@@ -140,13 +142,17 @@ namespace Banshee.FileSystemQueue
 
                     importer.Finished += delegate {
                         if (visible) {
-                            Banshee.Base.ThreadAssist.ProxyToMain (delegate {
-                                ServiceManager.SourceManager.SetActiveSource (this);
+                            ThreadAssist.ProxyToMain (delegate {
+                                TrackInfo current_track = ServiceManager.PlaybackController.CurrentTrack;
+                                // Don't switch to FSQ if the current item is a video
+                                if (current_track == null || !current_track.HasAttribute (TrackMediaAttributes.VideoStream)) {
+                                	ServiceManager.SourceManager.SetActiveSource (this);
+                                }
                             });
                         }
                     };
                 }
-            
+
                 if (PlaylistFileUtil.PathHasPlaylistExtension (path)) {
                     Banshee.Kernel.Scheduler.Schedule (new DelegateJob (delegate {
                         // If it's in /tmp it probably came from Firefox - just play it
@@ -161,29 +167,27 @@ namespace Banshee.FileSystemQueue
                 }
             }
         }
-        
+
         private void PlayEnqueued ()
-        {   
+        {
             if (!play_enqueued || path_to_play == null) {
                 return;
             }
-            
+
             SafeUri uri = null;
-            
+
             ServiceManager.PlaybackController.NextSource = this;
-            
+
             try {
                 uri = new SafeUri (path_to_play);
             } catch {
             }
-            
+
             if (uri == null) {
                 return;
             }
-            
-            int id = DatabaseTrackInfo.GetTrackIdForUri (uri, Paths.MakePathRelative (
-                uri.AbsolutePath, BaseDirectory), new int [] { DbId });
-            
+
+            int id = DatabaseTrackInfo.GetTrackIdForUri (uri, new int [] { DbId });
             if (id >= 0) {
                 int index = (int)TrackCache.IndexOf ((long)id);
                 if (index >= 0) {
@@ -195,7 +199,7 @@ namespace Banshee.FileSystemQueue
                 }
             }
         }
-        
+
         public override void Dispose ()
         {
             ServiceManager.Get<DBusCommandService> ().ArgumentPushed -= OnCommandLineArgument;
@@ -204,7 +208,7 @@ namespace Banshee.FileSystemQueue
             }
             base.Dispose ();
         }
-        
+
         private void OnCommandLineArgument (string argument, object value, bool isFile)
         {
             if (!isFile) {
@@ -214,9 +218,9 @@ namespace Banshee.FileSystemQueue
                 }
                 return;
             }
-            
+
             Log.DebugFormat ("FSQ Enqueue: {0}", argument);
-            
+
             try {
                 if (Banshee.IO.Directory.Exists (argument) || Banshee.IO.File.Exists (new SafeUri (argument))) {
                     Enqueue (argument);
@@ -224,16 +228,20 @@ namespace Banshee.FileSystemQueue
             } catch {
             }
         }
-        
+
         protected override void OnUpdated ()
         {
             base.OnUpdated ();
-            
+
             if (actions_loaded) {
                 UpdateActions ();
             }
         }
-        
+
+        public override bool HasEditableTrackProperties {
+            get { return true; }
+        }
+
         private void OnTrackModelReloaded (object sender, EventArgs args)
         {
             if (Count > 0 && !visible) {
@@ -243,12 +251,12 @@ namespace Banshee.FileSystemQueue
                 ServiceManager.SourceManager.RemoveSource (this);
                 visible = false;
             }
-            
+
             if (Count > 0) {
                 PlayEnqueued ();
             }
         }
-        
+
         private void OnClearFileSystemQueue (object o, EventArgs args)
         {
             // Delete any child playlists
@@ -263,28 +271,28 @@ namespace Banshee.FileSystemQueue
             RemoveTrackRange ((DatabaseTrackListModel)TrackModel, new Hyena.Collections.RangeCollection.Range (0, Count));
             Reload ();
         }
-        
+
         private void OnClearFileSystemQueueOnQuit (object o, EventArgs args)
         {
             InterfaceActionService uia_service = ServiceManager.Get<InterfaceActionService> ();
             if (uia_service == null) {
                 return;
             }
-            
+
             ToggleAction action = (ToggleAction)uia_service.GlobalActions["ClearFileSystemQueueOnQuitAction"];
             ClearOnQuitSchema.Set (action.Active);
         }
-        
+
         private void UpdateActions ()
-        {   
+        {
             InterfaceActionService uia_service = ServiceManager.Get<InterfaceActionService> ();
             if (uia_service == null) {
                 return;
             }
-            
+
             uia_service.GlobalActions.UpdateAction ("ClearFileSystemQueueAction", true, Count > 0);
         }
-        
+
         public static readonly SchemaEntry<bool> ClearOnQuitSchema = new SchemaEntry<bool> (
             "plugins.file_system_queue", "clear_on_quit",
             false,
